@@ -7,10 +7,17 @@
 # http://www.hardcoded.net/licenses/bsd_license
 
 from hsutil.testcase import TestCase as TestCaseBase
+from hsutil.testutil import TestData as TestDataBase
 from hsutil.path import Path
 
 class TestCase(TestCaseBase):
     @classmethod
     def datadirpath(cls):
         return Path(__file__)[:-1] + 'testdata'
-    
\ No newline at end of file
+    
+
+class TestData(TestDataBase):
+    @classmethod
+    def datadirpath(cls):
+        return Path(__file__)[:-1] + 'testdata'
+    
